DjOffers
========

.. image:: https://travis-ci.org/Stranger6667/djoffers.svg?branch=master
   :target: https://travis-ci.org/Stranger6667/djoffers
   :alt: Build Status

.. image:: https://codecov.io/github/Stranger6667/djoffers/coverage.svg?branch=master
   :target: https://codecov.io/github/Stranger6667/djoffers?branch=master
   :alt: Coverage Status

.. image:: https://readthedocs.org/projects/djoffers/badge/?version=latest
   :target: http://djoffers.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Django models for `HasOffers API <http://developers.hasoffers.com/>`_.

Installation
============

DjOffers can be obtained with ``pip``::

    $ pip install djoffers

Documentation
=============

You can view documentation online at:

- https://djoffers.readthedocs.io

Or you can look at the docs/ directory in the repository.

Python support
==============

DjOffers supports Python 3.4+ and Django 1.9+
